==> qexercise_0.1-1.tar.gz: qexercise-0.1/src/fooddialog.cpp <==
#include "fooddialog.h"
#include <QtDebug>
FoodDialog::FoodDialog(QWidget *parent)
{
    setAttribute(Qt::WA_Maemo5StackedWindow);
    setAttribute(Qt::WA_Maemo5PortraitOrientation);

    setWindowTitle("Add calories");

    xml = new XML();

    vLayout = new QVBoxLayout();

    modelName = new QStandardItemModel(this);

    btnName = new QMaemo5ValueButton("Product");
    btnName->setValueLayout(QMaemo5ValueButton::ValueUnderText);
    selectorName = new QMaemo5ListPickSelector;
    selectorName->setModel(modelName);
    btnName->setPickSelector(selectorName);


    modelAmount = new QStandardItemModel(this);
    for (int i = 1; i < 100; i++)
        modelAmount->appendRow(new QStandardItem(tr("%1").arg(i*5)));

    btnAmount = new QMaemo5ValueButton("Amount");
    btnAmount->setValueLayout(QMaemo5ValueButton::ValueUnderText);
    selectorAmount = new QMaemo5ListPickSelector;
    selectorAmount->setModel(modelAmount);
    btnAmount->setPickSelector(selectorAmount);

    btnAdd = new QPushButton("Add");
    connect(btnAdd,SIGNAL(clicked()),this,SLOT(save()));

    vLayout->addWidget(btnName);
    vLayout->addWidget(btnAmount);
    vLayout->addWidget(btnAdd);

    setLayout(vLayout);


}

void FoodDialog::load()
{
    QList <QString> food = xml->openIngredients();
    modelName->clear();
    while(!food.isEmpty())
    {
        modelName->appendRow(new QStandardItem(food.takeFirst()));
    }
    modelName->sort(0);
}

void FoodDialog::save()
{
    int kcal = xml->getCaloriesByName(btnName->valueText());

    kcal *= btnAmount->valueText().toInt();
    kcal /= 100;
    QString tmp; tmp.setNum(kcal);
    xml->saveEatenFood(tmp);
    hide();
}

==> qexercise_0.1-4.tar.gz: qexercise-0.1/src/fooddialog.cpp <==
#include "fooddialog.h"
#include <QtDebug>
FoodDialog::FoodDialog(QWidget *parent)
{
    setAttribute(Qt::WA_Maemo5StackedWindow);
    setAttribute(Qt::WA_Maemo5PortraitOrientation);

    setWindowTitle("Add calories");

    xml = new XML();

    vLayout = new QVBoxLayout();

    modelName = new QStandardItemModel(this);

    btnName = new QMaemo5ValueButton("Product");
    btnName->setValueLayout(QMaemo5ValueButton::ValueUnderText);
    selectorName = new QMaemo5ListPickSelector;
    selectorName->setModel(modelName);
    btnName->setPickSelector(selectorName);


    modelAmount = new QStandardItemModel(this);
    for (int i = 1; i < 100; i++)
        modelAmount->appendRow(new QStandardItem(tr("%1").arg(i*5)));

    btnAmount = new QMaemo5ValueButton("Amount (g)");
    btnAmount->setValueLayout(QMaemo5ValueButton::ValueUnderText);
    selectorAmount = new QMaemo5ListPickSelector;
    selectorAmount->setModel(modelAmount);
    btnAmount->setPickSelector(selectorAmount);

    btnAdd = new QPushButton("Add");
    connect(btnAdd,SIGNAL(clicked()),this,SLOT(save()));

    vLayout->addWidget(btnName);
    vLayout->addWidget(btnAmount);
    vLayout->addWidget(btnAdd);

    setLayout(vLayout);


}

void FoodDialog::load()
{
    QList <QString> food = xml->openIngredients();
    modelName->clear();
    while(!food.isEmpty())
    {
        modelName->appendRow(new QStandardItem(food.takeFirst()));
    }
    modelName->sort(0);
}

void FoodDialog::save()
{
    int kcal = xml->getCaloriesByName(btnName->valueText());

    kcal *= btnAmount->valueText().toInt();
    kcal /= 100;
    QString tmp; tmp.setNum(kcal);
    xml->saveEatenFood(tmp);
    hide();
}
